#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-packaging
version:              2.3.1
visibility:           public
id:                   hslua-packaging-2.3.1-4pSKeXnzmdYDqoQde47g4S
key:                  hslua-packaging-2.3.1-4pSKeXnzmdYDqoQde47g4S
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Utilities to build Lua modules.
description:
    Utilities to package up Haskell functions and
    values into a Lua module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  06ad594fecda70433f45f68dd2661e66
exposed:              True
exposed-modules:
    HsLua.Packaging HsLua.Packaging.Convenience
    HsLua.Packaging.Documentation HsLua.Packaging.Function
    HsLua.Packaging.Module HsLua.Packaging.Rendering
    HsLua.Packaging.Types HsLua.Packaging.UDType

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-packaging-2.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-packaging-2.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-packaging-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-packaging
hs-libraries:         HShslua-packaging-2.3.1-4pSKeXnzmdYDqoQde47g4S
depends:
    base-4.18.2.1 containers-0.6.7
    hslua-core-2.3.2.1-3tsNfZ2PPMpIrGoJYp3SDj
    hslua-marshalling-2.3.2-EQCZTvqDYkhHetwO8kOojF
    hslua-objectorientation-2.3.1-2zJu8nKSSdxCUQNnxyfl9u
    hslua-typing-0.1.1-AicHKRlaLWcJSxT7T71kDy mtl-2.3.1 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-packaging/html/hslua-packaging.haddock

haddock-html:         /usr/share/doc/haskell-hslua-packaging/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

